@@ -639,9 +639,10 @@ __END__
 
 Net::Gitlab - Talk to a Gitlab installation via its API.
 
-=head1 VERSION
+=head1 DEPRECATED
 
-  This document describes v0.05 of Net::Gitlab - released October 07, 2014 as part of Net-Gitlab.
+This module is no longer being maintained.
+Please see L<GitLab::API::v4> as an alternative.
 
 =head1 METHODS
 
@@ -655,12 +656,15 @@ See perlmodinstall for information and options on installing Perl modules.
 
 =head1 SOURCE
 
-The development version is on github at L<http://https://github.com/harleypig/Net-Gitlab>
-and may be cloned from L<git://https://github.com/harleypig/Net-Gitlab.git>
+The development version is on github at L<https://github.com/bluefeet/Net-Gitlab>.
 
-=head1 AUTHOR
+=head1 ORIGINAL AUTHOR
 
-Alan Young <harleypig@gmail.com>
+Alan Young <harleypigE<64>gmail.com>
+
+=head1 CURRENT MAINTAINER
+
+Aran Clary Deltac <bluefeetE<64>gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
